result library

Classes

Err<T, E extends Object>
Wrapper type indicating the value is an Error or exception.
Ok<T, E extends Object>
Wrapper type indicating the value is Ok.
Result<T, E extends Object>
A wrapper type that may either be an error or a value.

Typedefs

ErrorHandler<T, E extends Object> = T Function(E error)
A callback function to handle errors within the application.
ResultCallback<T> = void Function(T value)
A callback function to handle the result.